@@ -22,6 +22,7 @@ from weave.flow.scorer import Scorer
 from weave.initialization import *
 from weave.object.obj import Object
 from weave.prompt.prompt import EasyPrompt, MessagesPrompt, Prompt, StringPrompt
+from weave.trace.log_call import log_call
 from weave.trace.util import Thread as Thread
 from weave.trace.util import ThreadPoolExecutor as ThreadPoolExecutor
 from weave.type_handlers.Audio.audio import Audio
@@ -63,6 +64,7 @@ __docspec__ = [
     Monitor,
     SavedView,
     Audio,
+    log_call,
 ]
 
 __all__ = [
@@ -90,6 +92,7 @@ __all__ = [
     "get",
     "get_current_call",
     "init",
+    "log_call",
     "op",
     "publish",
     "ref",
