@@ -4,6 +4,12 @@ import importlib
 from functools import wraps
 from typing import TYPE_CHECKING, Any, Callable
 
+from google.cloud.aiplatform_v1beta1.types import content as gapic_content_types
+from google.cloud.aiplatform_v1beta1.types import (
+    prediction_service as gapic_prediction_service_types,
+)
+from vertexai.generative_models import GenerationResponse
+
 import weave
 from weave.integrations.patcher import MultiPatcher, NoOpPatcher, SymbolPatcher
 from weave.trace.autopatch import IntegrationSettings, OpSettings
@@ -12,7 +18,7 @@ from weave.trace.op import _add_accumulator
 from weave.trace.serialization.serialize import dictify
 
 if TYPE_CHECKING:
-    from vertexai.generative_models import GenerationResponse
+    pass
 
 
 _vertexai_patcher: MultiPatcher | None = None
@@ -33,12 +39,6 @@ def vertexai_postprocess_inputs(inputs: dict[str, Any]) -> dict[str, Any]:
 def vertexai_accumulator(
     acc: GenerationResponse | None, value: GenerationResponse
 ) -> GenerationResponse:
-    from google.cloud.aiplatform_v1beta1.types import content as gapic_content_types
-    from google.cloud.aiplatform_v1beta1.types import (
-        prediction_service as gapic_prediction_service_types,
-    )
-    from vertexai.generative_models import GenerationResponse
-
     if acc is None:
         return value
 
