@@ -2,14 +2,16 @@ import json
 from typing import Any
 
 import weave
-from weave.scorers.base_scorer import Scorer
+from weave.flow.scorer import Scorer
+from weave.trace.objectify import register_object
 
 
+@register_object
 class ValidJSONScorer(Scorer):
     """Validate whether a string is valid JSON."""
 
     @weave.op
-    def score(self, output: Any) -> dict:
+    def score(self, *, output: Any, **kwargs: Any) -> dict:
         try:
             _ = json.loads(output)
         except json.JSONDecodeError:
