@@ -1,21 +1,20 @@
-from typing import Callable
+from typing import Any, Callable
 
 from pydantic import Field, model_validator
 
 import weave
-from weave.scorers.base_scorer import Scorer
 
 
-class StringMatchScorer(Scorer):
+class StringMatchScorer(weave.Scorer):
     """Scorer that checks if the model output string is found in the search columns of the dataset row."""
 
     @weave.op
-    def score(self, output: str, target: str) -> dict:
+    def score(self, *, output: str, target: str, **kwargs: Any) -> dict:
         string_in_input = output.lower() in target.lower()
         return {"string_in_input": string_in_input}
 
 
-class LevenshteinScorer(Scorer):
+class LevenshteinScorer(weave.Scorer):
     distance: Callable[[str, str], int] = Field(
         default=None, description="The Levenshtein distance function"
     )
@@ -29,11 +28,11 @@ class LevenshteinScorer(Scorer):
         except ImportError:
             raise ValueError(
                 "Levenshtein package not found. Please install it with `pip install Levenshtein`"
-            )
+            ) from None
         else:
             return self
 
     @weave.op
-    def score(self, output: str, target: str) -> dict:
+    def score(self, *, output: str, target: str, **kwargs: Any) -> dict:
         distance = self.distance(output, target)
         return {"levenshtein_distance": distance}
