@@ -1,7 +1,6 @@
 from urllib.parse import quote
 
-from wandb import util as wb_util
-
+from weave.compat import wandb
 from weave.trace import env
 
 BROWSE3_PATH = "browse3"
@@ -9,17 +8,11 @@ WEAVE_SLUG = "weave"
 
 
 def remote_project_root_url(entity_name: str, project_name: str) -> str:
-    return (
-        f"{wb_util.app_url(env.wandb_base_url())}/{entity_name}/{quote(project_name)}"
-    )
-
-
-def remote_project_weave_root_url(entity_name: str, project_name: str) -> str:
-    return f"{remote_project_root_url(entity_name, project_name)}/{WEAVE_SLUG}"
+    return f"{wandb.app_url(env.wandb_base_url())}/{entity_name}/{quote(project_name)}"
 
 
 def project_weave_root_url(entity_name: str, project_name: str) -> str:
-    return remote_project_weave_root_url(entity_name, project_name)
+    return f"{remote_project_root_url(entity_name, project_name)}/{WEAVE_SLUG}"
 
 
 def op_version_path(
