@@ -14,7 +14,7 @@ MAX_CALLS_STREAM_BATCH_SIZE = 500
 
 
 # ClickHouse size limits and error handling
-CLICKHOUSE_SINGLE_ROW_INSERT_BYTES_LIMIT = 7 * 1024 * 1024  # 7 MiB
+CLICKHOUSE_SINGLE_ROW_INSERT_BYTES_LIMIT = 3.5 * 1024 * 1024  # 3.5 MiB
 CLICKHOUSE_MAX_FEEDBACK_PAYLOAD_SIZE = 1 * 1024 * 1024  # 1 MiB
 ENTITY_TOO_LARGE_PAYLOAD = '{"_weave": {"error":"<EXCEEDS_LIMITS>"}}'
 
