@@ -282,7 +282,10 @@ class Span:
         )
 
     def to_call(
-        self, project_id: str, wb_user_id: Optional[str] = None
+        self,
+        project_id: str,
+        wb_user_id: Optional[str] = None,
+        wb_run_id: Optional[str] = None,
     ) -> tuple[tsi.StartedCallSchemaForInsert, tsi.EndedCallSchemaForInsert]:
         events = [SpanEvent(e.as_dict()) for e in self.events]
         usage = get_weave_usage(self.attributes) or {}
@@ -335,11 +338,15 @@ class Span:
         has_outputs = isinstance(outputs, int) or len(outputs) > 0
         has_usage = len(usage) > 0
 
-        # We failed to load any of the Weave attributes, dump all attributes
+        # Load user defined attributes - tagging system
+        if custom_attributes := wandb_attributes.get("attributes"):
+            attributes.update(custom_attributes)
+
+        # We failed to load any weave or user defined attributes, dump all attributes
         if not has_attributes and not has_inputs and not has_outputs and not has_usage:
             attributes = to_json_serializable(self.attributes)
 
-        attributes["otel_span"] = self.as_dict()
+        otel_span_data = self.as_dict()
         op_name = self.name
 
         display_name = wandb_attributes.get("display_name")
@@ -352,6 +359,20 @@ class Span:
         else:
             turn_id = None
 
+        ### START HACK
+        # If wb_run_id is defined here - then it came in from the headers
+        # If it contains a '/' then it is a malformed conversion in adapting layer
+        # If it doesn't contain a ':' while this is defined from headers it is a malformed conversion in adapting layer
+        # If it does contain a ':' while this is not defined and the attribute field is defined, again we have a malformed value
+        if not wb_run_id:  # headers not defined
+            attr_wb_run_id = wandb_attributes.get("wb_run_id") or None
+            if attr_wb_run_id and not ("/" in attr_wb_run_id or ":" in attr_wb_run_id):
+                wb_run_id = f"{project_id}:{attr_wb_run_id}"
+        ### END HACK
+
+        wb_run_step = wandb_attributes.get("wb_run_step") or None
+        wb_run_step_end = wandb_attributes.get("wb_run_step_end") or None
+
         if display_name and len(display_name) >= MAX_DISPLAY_NAME_LENGTH:
             display_name = shorten_name(display_name, MAX_DISPLAY_NAME_LENGTH)
 
@@ -384,9 +405,11 @@ class Span:
             started_at=start_time,
             attributes=attributes,
             inputs=inputs,
+            otel_dump=otel_span_data,
             display_name=display_name,
             wb_user_id=wb_user_id,
-            wb_run_id=None,
+            wb_run_id=wb_run_id,
+            wb_run_step=wb_run_step,
             turn_id=turn_id,
             thread_id=thread_id,
         )
@@ -402,6 +425,7 @@ class Span:
             exception=exception_msg,
             output=outputs,
             summary=summary_map,
+            wb_run_step_end=wb_run_step_end,
         )
         return (start_call, end_call)
 
