@@ -8,7 +8,6 @@ import os
 import re
 import subprocess
 import sys
-import uuid
 from pathlib import Path
 from typing import Annotated, Any, Generic
 from urllib.parse import quote_from_bytes, urlparse
@@ -55,7 +54,6 @@ class Content(BaseModel, Generic[T]):
 
     # This is required due to some attribute setting done by our serialization layer
     # Without it, it is hard to know if it was processed properly
-    id: str
     data: bytes
     size: int
     mimetype: str
@@ -75,7 +73,6 @@ class Content(BaseModel, Generic[T]):
             examples=[{"number of cats": 1}],
         ),
     ] = None
-    path: str | None = None
     extension: str | None = None
 
     _last_saved_path: Annotated[
@@ -110,7 +107,6 @@ class Content(BaseModel, Generic[T]):
         if isinstance(obj, dict):
             # Check if this is a full Content dict (from deserialization)
             required_fields = {
-                "id",
                 "data",
                 "size",
                 "mimetype",
@@ -181,7 +177,6 @@ class Content(BaseModel, Generic[T]):
         )
 
         resolved_args: ResolvedContentArgs = {
-            "id": uuid.uuid4().hex,
             "data": data,
             "size": size,
             "mimetype": mimetype,
@@ -231,7 +226,6 @@ class Content(BaseModel, Generic[T]):
         )
 
         resolved_args: ResolvedContentArgs = {
-            "id": uuid.uuid4().hex,
             "data": data,
             "size": size,
             "mimetype": mimetype,
@@ -283,7 +277,6 @@ class Content(BaseModel, Generic[T]):
         )
 
         resolved_args: ResolvedContentArgs = {
-            "id": uuid.uuid4().hex,
             "data": data,
             "size": size,
             "mimetype": mimetype,
@@ -332,7 +325,6 @@ class Content(BaseModel, Generic[T]):
 
         # We gather all the resolved arguments...
         resolved_args: ResolvedContentArgs = {
-            "id": uuid.uuid4().hex,
             "data": data,
             "size": file_size,
             "mimetype": mimetype,
@@ -340,7 +332,6 @@ class Content(BaseModel, Generic[T]):
             "filename": file_name,
             "content_type": "file",
             "input_type": full_name(path),
-            "path": str(path_obj.resolve()),
             "extension": extension,
             "encoding": encoding,
         }
@@ -376,7 +367,6 @@ class Content(BaseModel, Generic[T]):
         )
 
         resolved_args: ResolvedContentArgs = {
-            "id": uuid.uuid4().hex,
             "data": data,
             "size": size,
             "mimetype": mimetype,
@@ -452,7 +442,6 @@ class Content(BaseModel, Generic[T]):
         )
 
         resolved_args: ResolvedContentArgs = {
-            "id": uuid.uuid4().hex,
             "data": data,
             "size": size,
             "mimetype": mimetype,
@@ -558,7 +547,7 @@ class Content(BaseModel, Generic[T]):
         Returns:
             bool: True if the file was successfully opened, False otherwise.
         """
-        path = self._last_saved_path or self.path
+        path = self._last_saved_path
 
         if not path:
             logger.exception(
@@ -575,7 +564,7 @@ class Content(BaseModel, Generic[T]):
             else:  # linux variants
                 subprocess.call(("xdg-open", str(path)))
         except Exception as e:
-            logger.exception("Failed to open file %s", self.path)
+            logger.exception("Failed to open file %s", path)
             return False
         return True
 
