@@ -1,4 +1,4 @@
-"""The purpose of this utility is to simply ensure that a W&B project exists"""
+"""The purpose of this utility is to simply ensure that a W&B project exists."""
 # This file should be in the trace SDK dir
 
 import logging
@@ -34,10 +34,9 @@ def ensure_project_exists(entity_name: str, project_name: str) -> dict[str, str]
 
 
 def _ensure_project_exists(entity_name: str, project_name: str) -> dict[str, str]:
-    """
-    Ensures that a W&B project exists by trying to access it, returns the project_name,
+    """Ensures that a W&B project exists by trying to access it, returns the project_name,
     which is not guaranteed to be the same if the provided project_name contains invalid
-    characters. Adheres to trace_server_interface.EnsureProjectExistsRes
+    characters. Adheres to trace_server_interface.EnsureProjectExistsRes.
     """
     wandb_logging_disabled()
     api = wandb.Api()
